using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using SMSManager.SMSSend;
using Microsoft.Win32;

namespace SMSManager
{
    public partial class frmMain : Form
    {
        private int g_rowcount = 0;
        private int rowcount = 0;
        private DateTime date_from = DateTime.Now;
        private DateTime date_to = DateTime.Now;

        System.Threading.ThreadStart ts;
        System.Threading.Thread th;
        string FileName = "sms_report.csv";

        public frmMain()
        {
            InitializeComponent();
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            frmLogin login = new frmLogin();
            login.ShowDialog();
            if (!login.login_ok)
            {
                Application.Exit();
                return;
            }
            RegistryKey rk = Registry.CurrentUser.OpenSubKey("Software\\Inteliso\\SMSManager");
            if (rk == null)
                rk = Registry.CurrentUser.CreateSubKey("Software\\Inteliso\\SMSManager");
            if (rk.GetValue("use_ssl") != null && rk.GetValue("use_ssl").ToString() == "1")
                uywajSSLToolStripMenuItem.Checked = true;
            //checkBox1.Checked = true;
            comboBox1.SelectedIndex = 0;
            fill_balance();
            fill_report();
        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            fill_balance();
        }
        private void fill_balance()
        {
            SMSSender s = ((Globals.SSLRequired) ? s = Globals.SMS_ssl() : s = Globals.SMS());
            GenericRetObject ret = s.Balance(Globals.Username, Globals.Password);
            if (ret.Status == 1)
            {
                int bal = int.Parse(ret.val);
                lbl_balance.Text = ((bal > 0) ? bal / 15 : 0).ToString();
            }
        }
        private void fill_report()
        {
            try
            {
                this.g_rowcount = 0;
                SMSSender s = ((Globals.SSLRequired) ? s = Globals.SMS_ssl() : s = Globals.SMS());
                Row[] t = s.ReportGetSummary(Globals.Username, Globals.Password, dateTimePicker1.Value.ToShortDateString(), dateTimePicker2.Value.ToShortDateString());
                DataTable tbl = new DataTable();
                for (int i = 0; i < t.Length; i++)
                {
                    if (i == 0)
                    {
                        foreach (string col in t[i].fields)
                            tbl.Columns.Add(col);
                    }
                    if (t[i].items.Length > 0)
                    {
                        DataRow dr = tbl.NewRow();
                        dr.ItemArray = t[i].items;
                        tbl.Rows.Add(dr);
                        this.g_rowcount += int.Parse(dr["Ilosc"].ToString());
                    }
                }
                dataGridView1.DataSource = tbl;
                toolStripMenuItem3.Enabled = (tbl.Rows.Count > 0);
            }
            catch (Exception ex)
            {
                Globals.Log(ex);
            }
        }
        private void tmr_report_Tick(object sender, EventArgs e)
        {
            fill_report();
        }

        private void dateTimePicker1_ValueChanged(object sender, EventArgs e)
        {
            fill_report();
        }

        private void dateTimePicker2_ValueChanged(object sender, EventArgs e)
        {
            fill_report();
        }

        private void get_report_csv()
        {
            try
            {
                pictureBox1.Visible = true;
                toolStripMenuItem3.Enabled = false;
                this.Cursor = Cursors.WaitCursor;
                this.date_from = dateTimePicker1.Value;
                this.date_to = dateTimePicker2.Value;
                this.rowcount = this.g_rowcount;

                SaveFileDialog sd = new SaveFileDialog();
                sd.Filter = "plik csv (*.csv)|*.csv";
                sd.FileName = "sms_report_" + this.date_from.ToString("yyyy_MM_dd") + "_" + this.date_to.ToString("yyyy_MM_dd") + ".csv";
                if (sd.ShowDialog() == DialogResult.OK)
                {
                    this.FileName = sd.FileName;
                }
                else
                {
                    MessageBox.Show("Anulowano zapis!");
                    return;
                }

                ts = new System.Threading.ThreadStart(GetReportCSV);
                th = new System.Threading.Thread(ts);

                th.Start();
            }
            catch (Exception ex)
            {
                this.Cursor = Cursors.Default;
                pictureBox1.Visible = false;
                MessageBox.Show(ex.ToString());
                Globals.Log(ex);
            }
            finally
            {

            }
        }
        private void button1_Click(object sender, EventArgs e)
        {

        }

        private void GetReportCSV()
        {
            DataTable tbl = new DataTable();
            int r_limit = 200;
            for (int l = 0; l < this.rowcount; l += r_limit) //pobiranie raportu partiami
            {
                SMSSender s = ((Globals.SSLRequired) ? s = Globals.SMS_ssl() : s = Globals.SMS());
                Row[] t = s.ReportGet(Globals.Username, Globals.Password, this.date_from.ToShortDateString(), this.date_to.ToShortDateString(), l, r_limit);

                for (int i = 0; i < t.Length; i++)
                {
                    if (l == 0 && i == 0)//pierwsza ptla i pierwsze w ni wejcie
                    {
                        foreach (string col in t[i].fields)
                            tbl.Columns.Add(col);
                    }
                    DataRow dr = tbl.NewRow();
                    dr.ItemArray = t[i].items;
                    tbl.Rows.Add(dr);
                }
            }
            iofunctions.SaveToFileDT(tbl, FileName, char.Parse(";"));
        }

        private void checkBox1_CheckedChanged(object sender, EventArgs e)
        {
            /*Globals.SSLRequired = checkBox1.Checked;
            try
            {
                RegistryKey rk = Registry.CurrentUser.OpenSubKey("Software\\Inteliso\\SMSManager",true);
                if (rk != null)
                    rk.SetValue("use_ssl", ((checkBox1.Checked) ? "1" : "0"));
            }
            catch (Exception ex){
                Globals.Log(ex);
            }*/
        }

        private void tmr_get_csv_Tick(object sender, EventArgs e)
        {
            if (th != null && th.ThreadState == System.Threading.ThreadState.Running)
            {
                toolStripMenuItem3.Enabled = false;
                pictureBox1.Visible = true;
                this.Cursor = Cursors.WaitCursor;
            }
            else
            {
                this.Cursor = Cursors.Default;
                pictureBox1.Visible = false;
                toolStripMenuItem3.Enabled = (this.g_rowcount > 0);
            }
        }

        private void uywajSSLToolStripMenuItem_Click(object sender, EventArgs e)
        {
            uywajSSLToolStripMenuItem.Checked = (!uywajSSLToolStripMenuItem.Checked);
            Globals.SSLRequired = uywajSSLToolStripMenuItem.Checked;
            try
            {
                RegistryKey rk = Registry.CurrentUser.OpenSubKey("Software\\Inteliso\\SMSManager", true);
                if (rk != null)
                    rk.SetValue("use_ssl", ((uywajSSLToolStripMenuItem.Checked) ? "1" : "0"));
            }
            catch (Exception ex)
            {
                Globals.Log(ex);
            }
        }

        private void importCSVToolStripMenuItem_Click(object sender, EventArgs e)
        {
            frmImportCSV im = new frmImportCSV();
            im.ShowDialog();
        }

        private void toolStripMenuItem3_Click(object sender, EventArgs e)
        {
            get_report_csv();
        }

        private void toolStripMenuItem4_Click(object sender, EventArgs e)
        {
            fill_report();
        }

        private void pojedynczySMSToolStripMenuItem_Click(object sender, EventArgs e)
        {
            frmSMS fs = null;
            if (Globals.global_objects["frmSMS"] != null)
            {
                fs = (frmSMS)Globals.global_objects["frmSMS"];
                if (fs.IsDisposed)
                    fs = null;
            }
            if (fs == null)
            {
                fs = new frmSMS();
                fs.Show();
            }
            else
            {

                if (fs.WindowState == FormWindowState.Minimized)
                    fs.WindowState = FormWindowState.Normal;
                fs.Focus();
            }
            Globals.global_objects["frmSMS"] = fs;

        }

        private void quickCSVToolStripMenuItem_Click(object sender, EventArgs e)
        {
            frmQuickSMS fqs = null;
            if (Globals.global_objects["frmQuickSMS"] != null)
            {
                fqs = (frmQuickSMS)Globals.global_objects["frmQuickSMS"];
                if (fqs.IsDisposed)
                    fqs = null;
            }
            if (fqs == null)
            {
                fqs = new frmQuickSMS();
                fqs.Show();
            }
            else
            {

                if (fqs.WindowState == FormWindowState.Minimized)
                    fqs.WindowState = FormWindowState.Normal;
                fqs.Focus();
            }
            Globals.global_objects["frmQuickSMS"] = fqs;
        }

        private void groupBox1_Enter(object sender, EventArgs e)
        {

        }
    }
}